aboutsummaryrefslogtreecommitdiffstats
path: root/test/compilationTests/zeppelin/token/SimpleToken.sol
diff options
context:
space:
mode:
Diffstat (limited to 'test/compilationTests/zeppelin/token/SimpleToken.sol')
-rw-r--r--test/compilationTests/zeppelin/token/SimpleToken.sol6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/compilationTests/zeppelin/token/SimpleToken.sol b/test/compilationTests/zeppelin/token/SimpleToken.sol
index 898cb21d..d8717562 100644
--- a/test/compilationTests/zeppelin/token/SimpleToken.sol
+++ b/test/compilationTests/zeppelin/token/SimpleToken.sol
@@ -6,7 +6,7 @@ import "./StandardToken.sol";
/**
* @title SimpleToken
- * @dev Very simple ERC20 Token example, where all tokens are pre-assigned to the creator.
+ * @dev Very simple ERC20 Token example, where all tokens are pre-assigned to the creator.
* Note they can later distribute these tokens as they wish using `transfer` and other
* `StandardToken` functions.
*/
@@ -18,9 +18,9 @@ contract SimpleToken is StandardToken {
uint256 public INITIAL_SUPPLY = 10000;
/**
* @dev Contructor that gives msg.sender all of existing tokens.
*/
- function SimpleToken() {
+ constructor() public {
totalSupply = INITIAL_SUPPLY;
balances[msg.sender] = INITIAL_SUPPLY;
}
@@ -18,9 +18,9 @@ contract SimpleToken is StandardToken {
uint256 public INITIAL_SUPPLY = 10000;
/**
- * @dev Contructor that gives msg.sender all of existing tokens.
+ * @dev Constructor that gives msg.sender all of existing tokens.
*/